RKTK API Docs RKTK Home Repo

LayoutForDim

Trait LayoutForDim 

pub trait LayoutForDim<Dim> { }
Trait for associating layout types with dimension markers.

This trait creates the relationship between a layout type and its dimensionality, which helps enforce correct combinations at compile time.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<T> LayoutForDim<Dim1d> for T
where T: Layout1d,

All types implementing Layout1d are compatible with Dim1d.

Source

impl<T> LayoutForDim<Dim2d> for T
where T: Layout2d,

All types implementing Layout2d are compatible with Dim2d.

Source

impl<T> LayoutForDim<Dim3d> for T
where T: Layout3d,

All types implementing Layout3d are compatible with Dim3d.