pub trait LayoutForDim<Dim> { }Expand description
Trait for associating layout types with dimension markers.
This trait creates the relationship between a layout type and its dimensionality, which helps enforce correct combinations at compile time.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<T> LayoutForDim<Dim1d> for Twhere
T: Layout1d,
All types implementing Layout1d are compatible with Dim1d.
impl<T> LayoutForDim<Dim2d> for Twhere
T: Layout2d,
All types implementing Layout2d are compatible with Dim2d.
impl<T> LayoutForDim<Dim3d> for Twhere
T: Layout3d,
All types implementing Layout3d are compatible with Dim3d.
RKTK API Docs